@@ -1,16 +1,16 @@
 /* gtk-exif-entry-date.c
  *
- * Copyright  2001 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright © 2001 Lutz Müller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
@@ -20,28 +20,17 @@
 
 #include "config.h"
 #include "gtk-exif-entry-date.h"
+#include "gtk-exif-util.h"
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkradiobutton.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkcalendar.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtkcalendar.h>
-
-#include "gtk-exif-util.h"
+#include <gtk/gtk.h>
 
 #ifdef ENABLE_NLS
 #  include <libintl.h>
 #  undef _
-#  define _(String) dgettext (PACKAGE, String)
+#  define _(String) dgettext (GETTEXT_PACKAGE, String)
 #  ifdef gettext_noop
 #    define N_(String) gettext_noop (String)
 #  else
@@ -68,16 +57,28 @@ struct _GtkExifEntryDatePrivate {
 static GtkExifEntryClass *parent_class;
 
 static void
+#if GTK_CHECK_VERSION(3,0,0)
+gtk_exif_entry_date_destroy (GtkWidget *widget)
+#else
 gtk_exif_entry_date_destroy (GtkObject *object)
+#endif
 {
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkExifEntryDate *entry = GTK_EXIF_ENTRY_DATE (widget);
+#else
 	GtkExifEntryDate *entry = GTK_EXIF_ENTRY_DATE (object);
+#endif
 
 	if (entry->priv->entry) {
 		exif_entry_unref (entry->priv->entry);
 		entry->priv->entry = NULL;
 	}
 
+#if GTK_CHECK_VERSION(3,0,0)
+	GTK_WIDGET_CLASS (parent_class)->destroy (widget);
+#else
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+#endif
 }
 
 GTK_EXIF_FINALIZE (entry_date, EntryDate)
@@ -85,11 +86,19 @@ GTK_EXIF_FINALIZE (entry_date, EntryDate)
 static void
 gtk_exif_entry_date_class_init (gpointer g_class, gpointer class_data)
 {
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkWidgetClass *widget_class;
+	GObjectClass *gobject_class;
+
+	widget_class = GTK_WIDGET_CLASS (g_class);
+	widget_class->destroy = gtk_exif_entry_date_destroy;
+#else
 	GtkObjectClass *object_class;
 	GObjectClass *gobject_class;
 
 	object_class = GTK_OBJECT_CLASS (g_class);
 	object_class->destroy  = gtk_exif_entry_date_destroy;
+#endif
 
 	gobject_class = G_OBJECT_CLASS (g_class);
 	gobject_class->finalize = gtk_exif_entry_date_finalize;
@@ -116,13 +125,13 @@ gtk_exif_entry_date_load (GtkExifEntryDate *entry)
 	g_return_if_fail (GTK_EXIF_IS_ENTRY_DATE (entry));
 	p = entry->priv;
 
-	g_signal_handlers_block_matched (GTK_OBJECT (p->cal),
+	g_signal_handlers_block_matched (G_OBJECT (p->cal),
 				G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, entry);
-	g_signal_handlers_block_matched (GTK_OBJECT (p->a_hour),
+	g_signal_handlers_block_matched (G_OBJECT (p->a_hour),
 				G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, entry);
-	g_signal_handlers_block_matched (GTK_OBJECT (p->a_min),
+	g_signal_handlers_block_matched (G_OBJECT (p->a_min),
 				G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, entry);
-	g_signal_handlers_block_matched (GTK_OBJECT (p->a_sec),
+	g_signal_handlers_block_matched (G_OBJECT (p->a_sec),
 				G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, entry);
 
 	data = g_strdup (entry->priv->entry->data);
@@ -147,14 +156,18 @@ gtk_exif_entry_date_load (GtkExifEntryDate *entry)
 static void
 gtk_exif_entry_date_save (GtkExifEntryDate *entry)
 {
+	guint year, month, day;
+
 	g_return_if_fail (GTK_EXIF_IS_ENTRY_DATE (entry));
 
+	gtk_calendar_get_date (entry->priv->cal, &year, &month, &day);
 	sprintf (entry->priv->entry->data, "%04i:%02i:%02i %02i:%02i:%02i",
-		 entry->priv->cal->year, entry->priv->cal->month + 1,
-		 entry->priv->cal->selected_day,
-		 (gint) entry->priv->a_hour->value,
-		 (gint) entry->priv->a_min->value,
-		 (gint) entry->priv->a_sec->value);
+		 (gint) year,
+		 (gint) month + 1,
+		 (gint) day,
+		 (gint) gtk_adjustment_get_value(entry->priv->a_hour),
+		 (gint) gtk_adjustment_get_value(entry->priv->a_min),
+		 (gint) gtk_adjustment_get_value(entry->priv->a_sec));
 	gtk_exif_entry_changed (GTK_EXIF_ENTRY (entry), entry->priv->entry);
 }
 
@@ -175,25 +188,32 @@ gtk_exif_entry_date_new (ExifEntry *e)
 {
 	GtkExifEntryDate *entry;
 	GtkWidget *c, *hbox, *label, *spin;
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkAdjustment *a;
+#else
 	GtkObject *a;
+#endif
 
 	g_return_val_if_fail (e != NULL, NULL);
 	g_return_val_if_fail ((e->tag == EXIF_TAG_DATE_TIME) ||
 			      (e->tag == EXIF_TAG_DATE_TIME_ORIGINAL) ||
 			      (e->tag == EXIF_TAG_DATE_TIME_DIGITIZED), NULL);
 
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
 	entry = g_object_new (GTK_EXIF_TYPE_ENTRY_DATE, NULL);
 	entry->priv->entry = e;
 	exif_entry_ref (e);
 	gtk_exif_entry_construct (GTK_EXIF_ENTRY (entry),
-		exif_tag_get_title (e->tag),
-		exif_tag_get_description (e->tag));
+		exif_tag_get_title_in_ifd (e->tag, exif_content_get_ifd(e->parent)),
+		exif_tag_get_description_in_ifd (e->tag, exif_content_get_ifd(e->parent)));
 
 	c = gtk_calendar_new ();
 	gtk_widget_show (c);
 	gtk_box_pack_start (GTK_BOX (entry), c, TRUE, FALSE, 0);
 	entry->priv->cal = GTK_CALENDAR (c);
-	g_signal_connect (GTK_OBJECT (c), "day_selected",
+	g_signal_connect (G_OBJECT (c), "day_selected",
 			    G_CALLBACK (on_day_selected), entry);
 
 	hbox = gtk_hbox_new (FALSE, 5);
