@@ -1,16 +1,16 @@
 /* gtk-exif-entry-rational.c
  *
- * Copyright  2001 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright © 2001 Lutz Müller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
@@ -20,28 +20,16 @@
 
 #include "config.h"
 #include "gtk-exif-entry-rational.h"
+#include "gtk-exif-util.h"
 
 #include <string.h>
-
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkradiobutton.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktable.h>
-
+#include <gtk/gtk.h>
 #include <libexif/exif-utils.h>
 
-#include "gtk-exif-util.h"
-
 #ifdef ENABLE_NLS
 #  include <libintl.h>
 #  undef _
-#  define _(String) dgettext (PACKAGE, String)
+#  define _(String) dgettext (GETTEXT_PACKAGE, String)
 #  ifdef gettext_noop
 #    define N_(String) gettext_noop (String)
 #  else
@@ -67,9 +55,17 @@ struct _GtkExifEntryRationalPrivate {
 static GtkExifEntryClass *parent_class;
 
 static void
+#if GTK_CHECK_VERSION(3,0,0)
+gtk_exif_entry_rational_destroy (GtkWidget *widget)
+#else
 gtk_exif_entry_rational_destroy (GtkObject *object)
+#endif
 {
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkExifEntryRational *entry = GTK_EXIF_ENTRY_RATIONAL (widget);
+#else
 	GtkExifEntryRational *entry = GTK_EXIF_ENTRY_RATIONAL (object);
+#endif
 
 	if (entry->priv->entry) {
 		exif_entry_unref (entry->priv->entry);
@@ -86,7 +82,11 @@ gtk_exif_entry_rational_destroy (GtkObject *object)
 		entry->priv->aq = NULL;
 	}
 
+#if GTK_CHECK_VERSION(3,0,0)
+	GTK_WIDGET_CLASS (parent_class)->destroy (widget);
+#else
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+#endif
 }
 
 GTK_EXIF_FINALIZE (entry_rational, EntryRational)
@@ -94,11 +94,19 @@ GTK_EXIF_FINALIZE (entry_rational, EntryRational)
 static void
 gtk_exif_entry_rational_class_init (gpointer g_class, gpointer class_data)
 {
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkWidgetClass *widget_class;
+	GObjectClass *gobject_class;
+
+	widget_class = GTK_WIDGET_CLASS (g_class);
+	widget_class->destroy  = gtk_exif_entry_rational_destroy;
+#else
 	GtkObjectClass *object_class;
 	GObjectClass *gobject_class;
 
 	object_class = GTK_OBJECT_CLASS (g_class);
 	object_class->destroy  = gtk_exif_entry_rational_destroy;
+#endif
 
 	gobject_class = G_OBJECT_CLASS (g_class);
 	gobject_class->finalize = gtk_exif_entry_rational_finalize;
@@ -180,13 +188,13 @@ gtk_exif_entry_rational_save (GtkExifEntryRational *entry)
 		aq = entry->priv->aq->pdata[i];
 		switch (e->format) {
 		case EXIF_FORMAT_RATIONAL:
-			r.numerator = ap->value;
-			r.denominator = aq->value;
+			r.numerator = gtk_adjustment_get_value (ap);
+			r.denominator = gtk_adjustment_get_value (aq);
 			exif_set_rational (e->data + 8 * i, o, r);
 			break;
 		case EXIF_FORMAT_SRATIONAL:
-			sr.numerator = ap->value;
-			sr.denominator = aq->value;
+			sr.numerator = gtk_adjustment_get_value (ap);
+			sr.denominator = gtk_adjustment_get_value (aq);
 			exif_set_srational (e->data + 8 * i, o, sr);
 			break;
 		default:
@@ -194,7 +202,7 @@ gtk_exif_entry_rational_save (GtkExifEntryRational *entry)
 			return;
 		}
 	}
-	g_signal_emit_by_name (GTK_OBJECT (entry), "entry_changed", e);
+	g_signal_emit_by_name (G_OBJECT (entry), "entry_changed", e);
 }
 
 static void
@@ -208,7 +216,11 @@ gtk_exif_entry_rational_new (ExifEntry *e)
 {
 	GtkExifEntryRational *entry;
 	GtkWidget *table, *label, *spin;
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkAdjustment *a;
+#else
 	GtkObject *a;
+#endif
 	gchar *txt;
 	guint i;
 
@@ -216,12 +228,15 @@ gtk_exif_entry_rational_new (ExifEntry *e)
 	g_return_val_if_fail ((e->format == EXIF_FORMAT_RATIONAL) ||
 			      (e->format == EXIF_FORMAT_SRATIONAL), NULL);
 
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
 	entry = g_object_new (GTK_EXIF_TYPE_ENTRY_RATIONAL, NULL);
 	entry->priv->entry = e;
 	exif_entry_ref (e);
 	gtk_exif_entry_construct (GTK_EXIF_ENTRY (entry),
-		exif_tag_get_title (e->tag),
-		exif_tag_get_description (e->tag));
+		exif_tag_get_title_in_ifd (e->tag, exif_content_get_ifd(e->parent)),
+		exif_tag_get_description_in_ifd (e->tag, exif_content_get_ifd(e->parent)));
 
 	table = gtk_table_new (4, 1, FALSE);
 	gtk_widget_show (table);
