@@ -1,29 +1,36 @@
 /* gtk-exif-entry-user-comment.
  *
- * Copyright  2002 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright © 2002 Lutz Müller <lutz@users.sourceforge.net>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "gtk-exif-entry-user-comment.h"
+#include "gtk-exif-util.h"
+#include "gtk-extensions/gtk-options.h"
 
 #include <string.h>
 #include <stdlib.h>
-
-#include <gtk/gtklabel.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtkcombobox.h>
-
-#include "gtk-exif-util.h"
-
-#include "gtk-extensions/gtk-options.h"
+#include <gtk/gtk.h>
 
 #ifdef ENABLE_NLS
 #  include <libintl.h>
 #  undef _
-#  define _(String) dgettext (PACKAGE, String)
+#  define _(String) dgettext (GETTEXT_PACKAGE, String)
 #  ifdef gettext_noop
 #    define N_(String) gettext_noop (String)
 #  else
@@ -50,16 +57,28 @@ struct _GtkExifEntryUserCommentPrivate {
 static GtkExifEntryClass *parent_class;
 
 static void
+#if GTK_CHECK_VERSION(3,0,0)
+gtk_exif_entry_user_comment_destroy (GtkWidget *widget)
+#else
 gtk_exif_entry_user_comment_destroy (GtkObject *object)
+#endif
 {
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkExifEntryUserComment *entry = GTK_EXIF_ENTRY_USER_COMMENT (widget);
+#else
 	GtkExifEntryUserComment *entry = GTK_EXIF_ENTRY_USER_COMMENT (object);
+#endif
 
 	if (entry->priv->entry) {
 		exif_entry_unref (entry->priv->entry);
 		entry->priv->entry = NULL;
 	}
 
+#if GTK_CHECK_VERSION(3,0,0)
+	GTK_WIDGET_CLASS (parent_class)->destroy (widget);
+#else
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+#endif
 }
 
 GTK_EXIF_FINALIZE (entry_user_comment, EntryUserComment)
@@ -67,11 +86,19 @@ GTK_EXIF_FINALIZE (entry_user_comment, EntryUserComment)
 static void
 gtk_exif_entry_user_comment_class_init (gpointer g_class, gpointer class_data)
 {
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkWidgetClass *widget_class;
+	GObjectClass *gobject_class;
+
+	widget_class = GTK_WIDGET_CLASS (g_class);
+	widget_class->destroy = gtk_exif_entry_user_comment_destroy;
+#else
 	GtkObjectClass *object_class;
 	GObjectClass *gobject_class;
 
 	object_class = GTK_OBJECT_CLASS (g_class);
 	object_class->destroy  = gtk_exif_entry_user_comment_destroy;
+#endif
 
 	gobject_class = G_OBJECT_CLASS (g_class);
 	gobject_class->finalize = gtk_exif_entry_user_comment_finalize;
@@ -218,12 +245,15 @@ gtk_exif_entry_user_comment_new (ExifEntry *e)
 	g_return_val_if_fail (e->format == EXIF_FORMAT_UNDEFINED, NULL);
 	g_return_val_if_fail (e->tag == EXIF_TAG_USER_COMMENT, NULL);
 
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
 	entry = g_object_new (GTK_EXIF_TYPE_ENTRY_USER_COMMENT, NULL);
 	entry->priv->entry = e;
 	exif_entry_ref (e);
 	gtk_exif_entry_construct (GTK_EXIF_ENTRY (entry),
-		exif_tag_get_title (e->tag),
-		exif_tag_get_description (e->tag));
+		exif_tag_get_title_in_ifd (e->tag, exif_content_get_ifd(e->parent)),
+		exif_tag_get_description_in_ifd (e->tag, exif_content_get_ifd(e->parent)));
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
