@@ -1,16 +1,16 @@
 /* gtk-exif-entry.c
  *
- * Copyright  2001 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright © 2001 Lutz Müller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
@@ -20,16 +20,10 @@
 
 #include "config.h"
 #include "gtk-exif-entry.h"
+#include "gtk-exif-util.h"
 
 #include <string.h>
-
-#include <gtk/gtksignal.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkhseparator.h>
-
-#include "gtk-exif-util.h"
+#include <gtk/gtk.h>
 
 struct _GtkExifEntryPrivate {
 };
@@ -47,13 +41,26 @@ enum {
 static guint signals[LAST_SIGNAL] = {0};
 
 static void
+#if GTK_CHECK_VERSION(3,0,0)
+gtk_exif_entry_destroy (GtkWidget *widget)
+#else
 gtk_exif_entry_destroy (GtkObject *object)
+#endif
 {
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkExifEntry *entry = GTK_EXIF_ENTRY (widget);
+#else
 	GtkExifEntry *entry = GTK_EXIF_ENTRY (object);
+#endif
 
-	entry = NULL;
+	/* Nothing to free here */
+	(void)entry;
 
+#if GTK_CHECK_VERSION(3,0,0)
+	GTK_WIDGET_CLASS (parent_class)->destroy (widget);
+#else
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+#endif
 }
 
 GTK_EXIF_FINALIZE (entry, Entry)
@@ -61,11 +68,19 @@ GTK_EXIF_FINALIZE (entry, Entry)
 static void
 gtk_exif_entry_class_init (gpointer g_class, gpointer class_data)
 {
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkWidgetClass *widget_class;
+	GObjectClass *gobject_class;
+
+	widget_class = GTK_WIDGET_CLASS (g_class);
+	widget_class->destroy  = gtk_exif_entry_destroy;
+#else
 	GtkObjectClass *object_class;
 	GObjectClass *gobject_class;
 
 	object_class = GTK_OBJECT_CLASS (g_class);
 	object_class->destroy  = gtk_exif_entry_destroy;
+#endif
 
 	gobject_class = G_OBJECT_CLASS (g_class);
 	gobject_class->finalize = gtk_exif_entry_finalize;
@@ -164,6 +179,6 @@ void
 gtk_exif_entry_removed (GtkExifEntry *entry, ExifEntry *e)
 {
 	g_return_if_fail (GTK_EXIF_IS_ENTRY (entry));
-	
+
 	g_signal_emit (G_OBJECT (entry), signals[ENTRY_REMOVED], 0, e);
 }
